import { PartialFavorite, GDPRFavorites } from "../types/GDPRExtended";
import { TweetLikeContainer, TweetDateIndex } from "./TweetArchive";
import { TweetIndex } from "../types/Internal";
export declare class FavoriteArchive implements TweetLikeContainer<PartialFavorite> {
    protected _all: PartialFavorite[];
    protected _index: TweetIndex<PartialFavorite>;
    protected _date_index: TweetDateIndex<PartialFavorite>;
    protected fav_set: Set<string>;
    add(favs: GDPRFavorites | PartialFavorite[]): void;
    /**
     * Check if {tweet_id} has been favorited.
     */
    has(tweet_id: string): boolean;
    /**
     * Get favorites informations of {tweet_id}.
     *
     * If {tweet_id} is not favorited, returns `undefined`.
     */
    single(tweet_id: string): PartialFavorite;
    /**
     * @deprecated Use `.single()` instead.
     */
    get(tweet_id: string): PartialFavorite;
    month(month: string | number, year: string | number): PartialFavorite[];
    fromThatDay(start?: Date): PartialFavorite[];
    [Symbol.iterator](): Generator<PartialFavorite, void, undefined>;
    /**
     * Get all the registred favorites
     */
    get all(): PartialFavorite[];
    /**
     * Favorites sorted by year then months.
     *
     * Favs on `2010-10` are favorites than cannot be date classed.
     */
    get index(): TweetDateIndex<PartialFavorite>;
    /**
     * Get all favorited tweets in the archive, inside a Set for quick check (like old `archive.extended_gdpr.favorites`).
     */
    get registred(): Set<string>;
    /**
     * Number of favorites.
     */
    get length(): number;
    /** `true` if this archive's favorites supported "extended" properties: `.fullText` and `.expandedUrl`. */
    get has_extended_favorites(): boolean;
}
