"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const exported_helpers_1 = require("./exported_helpers");
function supportsBigInt() {
    return typeof BigInt !== 'undefined';
}
exports.supportsBigInt = supportsBigInt;
function dateOfDMEvent(event) {
    if (event.createdAtDate instanceof Date) {
        return event.createdAtDate;
    }
    return event.createdAtDate = exported_helpers_1.parseTwitterDate(event.createdAt);
}
exports.dateOfDMEvent = dateOfDMEvent;
function sleep(ms) {
    return new Promise(resolve => setTimeout(resolve, ms));
}
exports.sleep = sleep;
/**
 * Safe push a possibily huge number of elements in array.
 */
function safePusher(array, elements) {
    // Some engines does not like the splat operators with 50000 elements in
    // parameter, need to do some tricks to work it on
    const CHUNK_LEN = 50000;
    if (elements.length > CHUNK_LEN) {
        let i = 0;
        let chunk = elements.slice(i, i + CHUNK_LEN);
        while (chunk.length) {
            array.push(...chunk);
            chunk = elements.slice(i, i + CHUNK_LEN);
            i += CHUNK_LEN;
        }
    }
    else {
        array.push(...elements);
    }
}
exports.safePusher = safePusher;
async function initAdArchiveFromArchive(archive, ads) {
    try {
        const impressions = await archive.get('ad-impressions.js');
        for (const i of impressions) {
            ads.impressions.push(...i.ad.adsUserData.adImpressions.impressions);
        }
    }
    catch (e) { }
    try {
        const engagements = await archive.get('ad-engagements.js');
        for (const e of engagements) {
            ads.engagements.push(...e.ad.adsUserData.adEngagements.engagements);
            ads.impressions.push(...e.ad.adsUserData.adEngagements.engagements.map(e => e.impressionAttributes));
        }
    }
    catch (e) { }
    try {
        const ads_mobile = await archive.get('ad-mobile-conversions-attributed.js');
        for (const ad of ads_mobile) {
            ads.mobile_conversions.push(...ad.ad.adsUserData.attributedMobileAppConversions.conversions);
        }
    }
    catch (e) { }
    try {
        const ads_online = await archive.get('ad-online-conversions-attributed.js');
        for (const ad of ads_online) {
            ads.online_conversions.push(...ad.ad.adsUserData.attributedOnlineConversions.conversions);
        }
    }
    catch (e) { }
}
exports.initAdArchiveFromArchive = initAdArchiveFromArchive;
